package com.gluedin.sport

import android.os.Bundle
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import com.app.usecase.config.UserInfoAutoSignIn
import com.app.usecase.constants.GluedInConstants
import com.gluedin.sport.databinding.ActivityGluedinSampleBinding
import com.gluedin.sport.utils.PrefRepository
import com.plussaw.GluedInInitializer
import com.plussaw.config.login.GluedInSDKCallBack
import com.plussaw.config.login.GluedInSdkException

class GluedInSampleActivity : AppCompatActivity() {
    private var binding: ActivityGluedinSampleBinding? = null
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityGluedinSampleBinding.inflate(layoutInflater)
        setContentView(binding?.root)
        launchGluedInSdk()
    }

    private fun launchGluedInSdk() {
        val prefRepository = PrefRepository(this)
        val callback: GluedInSDKCallBack = object : GluedInSDKCallBack {

            override fun onAppAuthSuccess(
                isSuccess: Boolean,
                gluedInSdkException: GluedInSdkException?
            ) = Unit

            override fun onLoginRegistrationRequired(isLoginAction: Boolean) = Unit

            override fun onSdkExit() = Unit

            override fun onSdkInitSuccess(
                isSuccess: Boolean,
                gluedInSdkException: GluedInSdkException?
            ) {
                finish()
            }

            override fun onSdkLogout() = Unit
        }

        val configurations = GluedInInitializer.Configurations.Builder()
            .setLogEnabled(true, Log.VERBOSE)
            .setSdkCallback(callback)
            .setApiKey("put_your_api_key_here")
            .setSecretKey("put_your_secret_key_here")
            .setHttpLogEnabled(true, 3)
            .setDeeplinkAuthority("www.sample.com")
//            .setFeedType(GluedInInitializer.Configurations.FeedType.VERTICAL)// Vertical or Square
            .setUserInfoForAutoSignIn(
                UserInfoAutoSignIn(
                    prefRepository.getEmailId().toString(),
                    prefRepository.getPassword().toString(),
                    "Lima"
                )
            )
            .enableBackButton(true)
            .create()

        configurations.validateAndLaunchGluedInSDK(
            this,
            GluedInConstants.LaunchType.APP,
            intent
        )
    }
}