package com.gluedin.sport

import android.os.Bundle
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import androidx.fragment.app.FragmentTransaction
import androidx.navigation.NavGraph
import com.app.usecase.constants.GluedInConstants
import com.gluedin.sport.databinding.ActivityFashionMainBinding
import com.gluedin.sport.ui.fragments.MainFragment
import com.gluedin.sport.ui.fragments.SignInFragment
import com.gluedin.sport.utils.PrefRepository
import com.plussaw.GluedInInitializer
import com.plussaw.config.login.GluedInSDKCallBack
import com.plussaw.config.login.GluedInSdkException

class SportMainActivity : AppCompatActivity() {
    private var binding: ActivityFashionMainBinding? = null
    private var graph: NavGraph? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityFashionMainBinding.inflate(layoutInflater)
        setContentView(binding?.root)
        launchPlusSawSdk()
    }

    private fun launchPlusSawSdk() {
        val callback: GluedInSDKCallBack = object : GluedInSDKCallBack {

            override fun onAppAuthSuccess(
                isSuccess: Boolean,
                gluedInSdkException: GluedInSdkException?
            ) = Unit

            override fun onLoginRegistrationRequired(isLoginAction: Boolean) = Unit

            override fun onSdkExit() = Unit

            override fun onSdkInitSuccess(
                isSuccess: Boolean,
                gluedInSdkException: GluedInSdkException?
            ) {
                if (isSuccess) {
                    loadFragment()
                } else {
                    Toast.makeText(
                        this@SportMainActivity,
                        "GluedIn SDK Launched Failed",
                        Toast.LENGTH_SHORT
                    ).show()
                }
            }

            override fun onSdkLogout() = Unit
        }

        val configurations = GluedInInitializer.Configurations.Builder()
            .setLogEnabled(true, Log.VERBOSE)
            .setSdkCallback(callback)
            .setApiKey("put_your_api_key_here")
            .setSecretKey("put_your_secret_key_here")
            .setHttpLogEnabled(true, 3)
            .setDeeplinkAuthority("www.sample.com")
            .setFeedType(GluedInInitializer.Configurations.FeedType.VERTICAL)
            .create()

        configurations.validateGluedInSDK(
            this,
            GluedInConstants.LaunchType.SDK,
        )

    }

    private fun loadFragment() {
        var sampleWidgetFragment: Fragment = SignInFragment()
        val prefRepository =  PrefRepository(this)
        if (prefRepository.getLoggedIn()) {
            sampleWidgetFragment = MainFragment()
        }
        val fm: FragmentManager = supportFragmentManager
        val fragmentTransaction: FragmentTransaction = fm.beginTransaction()
        fragmentTransaction.replace(R.id.main_nav_host_fragment, sampleWidgetFragment)
        fragmentTransaction.addToBackStack(null)
        fragmentTransaction.commit()
    }
}