package com.gluedin.sport.ui.adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.gluedin.sport.databinding.ItemBrandsBinding
import com.gluedin.sport.databinding.ItemCategoriesBinding
import com.gluedin.sport.databinding.ItemProductBinding
import com.gluedin.sport.entity.RailItem
import com.gluedin.sport.ui.viewType.*
import com.gluedin.sport.utils.DataType
import com.gluedin.sport.utils.ViewType

class RailAdapter(private val rail: List<RailItem>, private val type: String) :
    RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        when (viewType) {
            ViewType.CATEGORIES.value -> {
                val inflater = LayoutInflater.from(parent.context)
                val binding = ItemCategoriesBinding.inflate(inflater, parent, false)
                return CategoriesViewHolder(binding)
            }
            ViewType.FEATURED_PRODUCT.value -> {
                val inflater = LayoutInflater.from(parent.context)
                val binding = ItemProductBinding.inflate(inflater, parent, false)
                return ProductViewHolder(binding)
            }
            ViewType.BRANDS.value -> {
                val inflater = LayoutInflater.from(parent.context)
                val binding = ItemBrandsBinding.inflate(inflater, parent, false)
                return BrandViewHolder(binding)
            }
            ViewType.NEW_ARRIVAL.value -> {
                val inflater = LayoutInflater.from(parent.context)
                val binding = ItemProductBinding.inflate(inflater, parent, false)
                return ArrivalViewHolder(binding)
            }
            ViewType.NEW_LIKE.value -> {
                val inflater = LayoutInflater.from(parent.context)
                val binding = ItemProductBinding.inflate(inflater, parent, false)
                return LikeViewHolder(binding)
            }
            else -> {
                val inflater = LayoutInflater.from(parent.context)
                val binding = ItemCategoriesBinding.inflate(inflater, parent, false)
                return CategoriesViewHolder(binding)
            }
        }
    }

    override fun getItemCount(): Int {
        return rail.size
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val item = rail[position]
        when (holder) {
            is CategoriesViewHolder -> {
                val categoriesViewHolder: CategoriesViewHolder = holder
                categoriesViewHolder.bind(item, position)
            }
            is ProductViewHolder -> {
                val productViewHolder: ProductViewHolder = holder
                productViewHolder.bind(item, position)
            }

            is BrandViewHolder -> {
                val brandViewHolder: BrandViewHolder = holder
                brandViewHolder.bind(item, position)
            }
            is ArrivalViewHolder -> {
                val arrivalViewHolder: ArrivalViewHolder = holder
                arrivalViewHolder.bind(item, position)
            }
            is LikeViewHolder -> {
                val likeViewHolder: LikeViewHolder = holder
                likeViewHolder.bind(item)
            }
        }
    }

    override fun getItemViewType(position: Int): Int {
        return when (type) {
            DataType.CATEGORIES.key -> {
                ViewType.CATEGORIES.value
            }
            DataType.FEATURED_PRODUCT.key -> {
                ViewType.FEATURED_PRODUCT.value
            }
            DataType.BRANDS.key -> {
                ViewType.BRANDS.value
            }
            DataType.NEW_ARRIVAL.key -> {
                ViewType.NEW_ARRIVAL.value
            }
            DataType.NEW_LIKE.key -> {
                ViewType.NEW_LIKE.value
            }
            else -> {
                ViewType.CATEGORIES.value
            }
        }
    }

}