package com.gluedin.sport.ui.adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.fragment.app.FragmentActivity
import androidx.recyclerview.widget.RecyclerView
import com.gluedin.sport.databinding.WidgetItemBinding
import com.gluedin.sport.entity.Rail
import com.gluedin.sport.utils.DataType

class WidgetAdapter(private val widgetData: List<Rail>, private val context: FragmentActivity) :
    RecyclerView.Adapter<RecyclerView.ViewHolder>() {
    private companion object {
        const val GLUEDIN_WIDGET = 1
        const val FASHION_WIDGET = 2
        const val BANNER = 3
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        val inflater = LayoutInflater.from(parent.context)
        val binding = WidgetItemBinding.inflate(inflater, parent, false)
        return when (viewType) {
            GLUEDIN_WIDGET -> {
                GluedinWidgetViewHolder(binding)
            }
            BANNER -> {
                PopularViewHolder(binding)
            }
            else -> {
                WidgetViewHolder(binding)
            }
        }
    }

    override fun getItemCount(): Int {
        return widgetData.size
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val data = widgetData[position]
        when (holder) {
            is GluedinWidgetViewHolder -> {
                holder.onBind(data.gluedInRailId, data.railType, data.name, context)
            }
            is PopularViewHolder -> {
                holder.onBind(data.railItems, data.railType, data.name, context)
            }
            else -> {
                (holder as WidgetViewHolder).onBind(
                    data.railItems,
                    data.railType,
                    data.name,
                    context
                )
            }
        }
    }

    override fun getItemViewType(position: Int): Int {
        return if (DataType.GLUEDIN_WIDGET.key == widgetData[position].railType) {
            GLUEDIN_WIDGET
        } else if (DataType.POPULAR.key == widgetData[position].railType) {
            BANNER
        } else if (DataType.BANNER.key == widgetData[position].railType) {
            BANNER
        } else {
            FASHION_WIDGET
        }
    }
}