package com.gluedin.sport.ui.fragments

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.activity.OnBackPressedCallback
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.LinearLayoutManager
import com.gluedin.sport.GluedInSampleActivity
import com.gluedin.sport.R
import com.gluedin.sport.databinding.FragmentHomeBinding
import com.gluedin.sport.entity.HomeData
import com.gluedin.sport.ui.adapter.WidgetAdapter
import com.gluedin.sport.utils.changeTextColor
import com.google.gson.Gson
import java.io.IOException

class HomeFragment : Fragment() {

    var binding: FragmentHomeBinding? = null
    lateinit var data: HomeData
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        activity?.onBackPressedDispatcher?.addCallback(this, object : OnBackPressedCallback(true) {
            override fun handleOnBackPressed() {
                activity?.finish()
            }
        })
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        binding = FragmentHomeBinding.inflate(layoutInflater, container, false)
        return binding?.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        activity?.let {
            getJsonDataFromAsset(it)
        }
        setTitle()
        setListener()
    }

    private fun setTitle() {
        binding?.appName?.setText(
            resources.getString(R.string.app_name),
            TextView.BufferType.SPANNABLE
        )
        val regex = Regex("Flix")
        val color = ContextCompat.getColor(requireContext(), R.color.orange)
        binding?.appName?.changeTextColor(regex, color)
    }

    private fun setListener() {
        binding?.gluedin?.setOnClickListener {
            activity?.startActivity(Intent(activity, GluedInSampleActivity::class.java))
        }
    }

    private fun getJsonDataFromAsset(context: Context) {
        val jsonString: String
        val gson = Gson()
        try {
            jsonString = context.assets.open("sample_json_fashion.json").bufferedReader()
                .use { it.readText() }
            data = gson.fromJson(jsonString, HomeData::class.java)
            loadAdapter(data)

        } catch (ioException: IOException) {
            data = HomeData()
            ioException.printStackTrace()
        }
    }

    private fun loadAdapter(
        railData: HomeData,
    ) {
        activity?.let {
            val layoutMainFragment =
                LinearLayoutManager(context, GridLayoutManager.VERTICAL, false)
            val adapter = WidgetAdapter(railData.rails, it)
            binding?.recyclerView?.layoutManager = layoutMainFragment
            binding?.recyclerView?.adapter = adapter
        }
    }

}