package com.gluedin.sport.ui.fragments

import android.annotation.SuppressLint
import android.os.Bundle
import android.provider.Settings
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.activity.OnBackPressedCallback
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import com.app.usecase.sign.signIn.UserAuthenticationInteractor
import com.gluedin.sport.R
import com.gluedin.sport.databinding.FragmentSignInBinding
import com.gluedin.sport.utils.*
import com.plussaw.data.network.status.HttpGluedinStatus
import com.plussaw.domain.entities.signin.SignInReq
import com.plussaw.presentation.utils.extensions.hasMinimumLength

class SignInFragment : Fragment() {

    private var binding: FragmentSignInBinding? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        activity?.onBackPressedDispatcher?.addCallback(this, object : OnBackPressedCallback(true) {
            override fun handleOnBackPressed() {
                activity?.finish()
            }

        })
    }

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        // Inflate the layout for this fragment
        binding = FragmentSignInBinding.inflate(layoutInflater, container, false)
        return binding?.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        setTitle()
        setListener()
    }

    private fun setTitle() {
        binding?.tvApp?.setText(
            resources.getString(R.string.app_name),
            TextView.BufferType.SPANNABLE
        )
        val regex = Regex("Flix")
        val color = ContextCompat.getColor(requireContext(), R.color.orange)
        binding?.tvApp?.changeTextColor(regex, color)
    }

    private fun setListener() {
        val prefRepository = context?.let { PrefRepository(it) }
        binding?.tvNavToSignUp?.setOnClickListener {
            activity?.loadFragment(SignupFragment())
        }

        binding?.btnSignIn?.setOnClickListener {
            if (validData()) {
                if (prefRepository?.getEmailId() == binding?.etEmail?.text.toString()
                        .trim() && prefRepository.getPassword() == binding?.etPassword?.text.toString()
                ) {
                    gluedinSignIn()
                } else {
                    showToast("User not found")
                }
            }
        }
    }

    private fun validData(): Boolean {
        if (binding?.etEmail?.text?.isEmpty() == true) {
            showToast("Please enter a valid Email")
            binding?.etEmail?.requestFocus()
            return false
        }
        if (binding?.etPassword?.text?.isEmpty() == true) {
            showToast("Please enter a valid password")
            binding?.etPassword?.requestFocus()
            return false
        }
        if (binding?.etPassword?.text.toString().hasMinimumLength(AppContents.MIN_LENGTH_PASSWORD)
                .not()
        ) {
            showToast(getString(R.string.password_length))
            return false
        }
        return true
    }

    @SuppressLint("HardwareIds")
    private fun gluedinSignIn() {
        val prefRepository = activity?.let { PrefRepository(it) }
        val androidId = Settings.Secure.getString(
            activity?.contentResolver,
            Settings.Secure.ANDROID_ID
        )
        val requestSignIn = SignInReq(
            password = prefRepository?.getPassword().toString(),
            email = prefRepository?.getEmailId().toString(),
            firebaseToken = "gdjsgfkjs",
            deviceId = androidId,
            deviceType = "android",
            fullName = "Lima",
            autoCreate = true,
        )
        val signin = UserAuthenticationInteractor()
        signin.authenticateUser(requestSignIn) { _, signInInfo ->
            if (HttpGluedinStatus.DATA_FOUND.value == signInInfo?.statusCode) {
                prefRepository?.setLoggedIn(true)
                activity?.loadFragment(MainFragment())
            } else {
                showToast("Something went wrong")
            }
        }
    }
}