package com.gluedin.sport.ui.fragments

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.core.content.ContextCompat
import androidx.fragment.app.Fragment
import com.gluedin.sport.R
import com.gluedin.sport.databinding.FragmentSignupBinding
import com.gluedin.sport.utils.AppContents.MIN_LENGTH_PASSWORD
import com.gluedin.sport.utils.PrefRepository
import com.gluedin.sport.utils.changeTextColor
import com.gluedin.sport.utils.loadFragment
import com.gluedin.sport.utils.showToast
import com.plussaw.presentation.utils.extensions.hasMinimumLength
import com.plussaw.presentation.utils.extensions.validateEmail

class SignupFragment : Fragment() {

    private var binding: FragmentSignupBinding? = null

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        // Inflate the layout for this fragment
        binding = FragmentSignupBinding.inflate(layoutInflater, container, false)
        return binding?.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        setTitle()
        setListener()
    }

    private fun setTitle() {
        binding?.tvApp?.setText(
            resources.getString(R.string.app_name),
            TextView.BufferType.SPANNABLE
        )
        val regex = Regex("Flix")
        val color = ContextCompat.getColor(requireContext(), R.color.orange)
        binding?.tvApp?.changeTextColor(regex, color)
    }

    private fun setListener() {
        binding?.tvNavToSignIn?.setOnClickListener {
            activity?.loadFragment(SignInFragment())
        }
        binding?.btnSignUp?.setOnClickListener {
            if (validData()) {
                context?.let { context ->
                    PrefRepository(context).setEmailId(binding?.etEmail?.text.toString())
                    PrefRepository(context).setPassword(binding?.etPassword?.text.toString())
                }
                activity?.loadFragment(SignInFragment())
            }
        }
    }

    private fun validData(): Boolean {
        if (binding?.etEmail?.text?.isEmpty() == true) {
            showToast("Please enter a valid Email")
            binding?.etEmail?.requestFocus()
            return false
        }
        if (binding?.etEmail?.text?.toString()?.validateEmail()?.not() == true) {
            showToast("Please enter a valid Email")
            binding?.etEmail?.requestFocus()
            return false
        }
        if (binding?.etPassword?.text?.isEmpty() == true) {
            showToast("Please enter a valid password")
            binding?.etPassword?.requestFocus()
            return false
        }
        if (binding?.etConfirmPassword?.text?.isEmpty() == true) {
            showToast("Please enter confirm password")
            binding?.etConfirmPassword?.requestFocus()
            return false
        }
        if (binding?.etConfirmPassword?.text?.toString() != binding?.etPassword?.text?.toString()) {
            showToast("password and confirm password should be same")
            binding?.etConfirmPassword?.requestFocus()
            return false
        }
        if (binding?.etPassword?.text.toString().hasMinimumLength(MIN_LENGTH_PASSWORD).not()) {
            showToast(getString(R.string.password_length))
            return false
        }
        return true
    }
}